def factor(x):
    j = []
    while True:
        try:
            if x<=0:
                print("\033[1;91m函数错误")
                exit()
            else:
                break
        except:
            print("\033[1;91m函数错误")
            exit()
    for i in range(x+1):
        if i >= 1:
            if x % i == 0:
                j.append(i)
    return j
def big(a, b):
    while True:
        try:
            if a == 0 or b == 0:
                print("\033[1;91m函数错误")
                exit()
            else:
                break
        except:
            print("\033[1;91m函数错误")
            exit()
    c = a % b
    while c != 0:
        a = b
        b = c
        c = a % b
    return b
def small(a, b):
    while True:
        try:
            if a == 0 or b == 0:
                print("\033[1;91m函数错误")
                exit()
            else:
                break
        except:
            print("\033[1;91m函数错误")
            exit()
    e = a
    f = b
    c = a % b
    while c != 0:
        a = b
        b = c
        c = a % b
    d = e*f/b
    return d


import setuptools
setuptools.setup(
    name='hymath',
    version='0.0.2',
    author='Dingdang Wang',
    author_email='1330274738@qq.com',
    description='学而思火焰工作室数学库',
    long_descripition_content_type="text/markdown",
    url='https://github.com/',
    packages=setuptools.find_packages(),
    classifiers= [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent" ,
    ],
)